pub struct CursorArea { /* private fields */ }Expand description
A container that changes the cursor icon when hovered.
When the component is dropped while still being hovered, the cursor is automatically reset to the default.
Example
fn app() -> impl IntoElement {
CursorArea::new().child("Hover me!")
}Implementations